@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
-#ifndef __ALSA_HINAWA_H__
-#define __ALSA_HINAWA_H__
+#ifndef __ORG_KERNEL_HINAWA_H__
+#define __ORG_KERNEL_HINAWA_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -15,18 +15,10 @@
 #include <hinawa_enums.h>
 
 #include <cycle_time.h>
-#include <snd_motu_register_dsp_parameter.h>
 
 #include <fw_node.h>
 #include <fw_resp.h>
 #include <fw_req.h>
 #include <fw_fcp.h>
 
-#include <snd_unit.h>
-#include <snd_dice.h>
-#include <snd_efw.h>
-#include <snd_dg00x.h>
-#include <snd_motu.h>
-#include <snd_tscm.h>
-
 #endif
